==> php55-owncloud-8.2.0.tgz: share/owncloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "نشاط",
    "Personal activity feed for %s" : "تغذية الأنشطة الشخصية ل %s",
    "Your feed URL is invalid" : "رابط التغدية الخاص بك غير شغال",
    "Your settings have been updated." : "تم تحديث الإعدادات الخاصة بك.",
    "Mail" : "البريد",
    "Stream" : "بث",
    "This stream will show events like additions, changes & shares" : "هذا التدفق سيظهر لك الاحداث، مثل الإضافة والتغيير والمشاركة",
    "There are no events for this filter" : "لا توجد هناك فعاليات وفق ما خصصته",
    "Activity notification" : "تنبيه النشاط",
    "All Activities" : "جميع النشاطات",
    "Activities by you" : "نشاطاتك",
    "Activities by others" : "نشاطات الآخرين",
    "\"remote user\"" : "\"عضوية التحكم\"",
    "in %s" : "في %s",
    "%s and %s" : "%s و %s",
    ", " : "،",
    "_%s and %n more_::_%s and %n more_" : ["%s و%n بعد","%s و%n بعد","%s و%n بعد","%s و%n بعد","%s و%n بعد","%s و%n بعد"],
    "Hello %s," : "مرحبا%so ,",
    "_* and %n more _::_* and %n more _" : ["* و %n بعد","* و %n بعد","* و %n بعد","* و %n بعد","* و %n بعد","* و %n بعد"],
    "Notifications" : "الإشعارات",
    "List your own actions in the stream" : "عدد أنشطتك",
    "Notify about your own actions via email" : "التنبيه عن أنشطتي عبر البريد الإلكتروني",
    "You need to set up your email address before you can receive notification emails." : "عليك إعداد عنوان البريد الإلكتروني الخاص بك قبل البدأ باستقبال رسائل إلكترونية تنبيهيه ",
    "Send emails:" : "إرسال رسائل إلكترونية ",
    "Hourly" : "مرة كل ساعة",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Activity feed" : "تغذية الأنشطة",
    "Enable RSS feed" : "تمكين التزويد بمقتطفات الأخبار أر أس أس",
    "No activity yet" : "لا يوجد أي أنشطة حتى الأن.",
    "No more events to load" : "لا توجد أي أحداث للتحميل",
    "Files" : "الملفات"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "نشاط",
    "Personal activity feed for %s" : "تغذية الأنشطة الشخصية ل %s",
    "Your feed URL is invalid" : "رابط التغدية الخاص بك غير شغال",
    "Your settings have been updated." : "تم تحديث الإعدادات الخاصة بك.",
    "Mail" : "البريد",
    "Stream" : "بث",
    ", " : "،",
    "This stream will show events like additions, changes & shares" : "هذا التدفق سيظهر لك الاحداث، مثل الإضافة والتغيير والمشاركة",
    "There are no events for this filter" : "لا توجد هناك فعاليات وفق ما خصصته",
    "Today" : "اليوم",
    "Yesterday" : "أمس",
    "\"remote user\"" : "\"عضوية التحكم\"",
    "Activity notification" : "تنبيه النشاط",
    "All Activities" : "جميع النشاطات",
    "Activities by you" : "نشاطاتك",
    "Activities by others" : "نشاطات الآخرين",
    "%s and %s" : "%s و %s",
    "Hello %s," : "مرحبا%so ,",
    "_* and %n more _::_* and %n more _" : ["* و %n بعد","* و %n بعد","* و %n بعد","* و %n بعد","* و %n بعد","* و %n بعد"],
    "List your own actions in the stream" : "عدد أنشطتك",
    "Notify about your own actions via email" : "التنبيه عن أنشطتي عبر البريد الإلكتروني",
    "You need to set up your email address before you can receive notification emails." : "عليك إعداد عنوان البريد الإلكتروني الخاص بك قبل البدأ باستقبال رسائل إلكترونية تنبيهيه ",
    "Send emails:" : "إرسال رسائل إلكترونية ",
    "Hourly" : "مرة كل ساعة",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Activity feed" : "تغذية الأنشطة",
    "Enable RSS feed" : "تمكين التزويد بمقتطفات الأخبار أر أس أس",
    "No activity yet" : "لا يوجد أي أنشطة حتى الأن.",
    "No more events to load" : "لا توجد أي أحداث للتحميل",
    "Files" : "الملفات"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
